summaryrefslogtreecommitdiffstats
path: root/kmyfirewall/core
diff options
context:
space:
mode:
Diffstat (limited to 'kmyfirewall/core')
-rw-r--r--kmyfirewall/core/ipaddress.cpp34
-rw-r--r--kmyfirewall/core/ipaddress.h10
-rw-r--r--kmyfirewall/core/kmfcheckinput.cpp20
-rw-r--r--kmyfirewall/core/kmfcheckinput.h2
-rw-r--r--kmyfirewall/core/kmfcompilerinterface.h2
-rw-r--r--kmyfirewall/core/kmfdoc.cpp4
-rw-r--r--kmyfirewall/core/kmfdoc.h2
-rw-r--r--kmyfirewall/core/kmfgenericdoc.cpp4
-rw-r--r--kmyfirewall/core/kmfiptdoc.cpp2
-rw-r--r--kmyfirewall/core/kmfnethost.cpp4
-rw-r--r--kmyfirewall/core/kmfnethost.h2
-rw-r--r--kmyfirewall/core/kmfnetwork.cpp4
-rw-r--r--kmyfirewall/core/kmfnetzone.cpp28
-rw-r--r--kmyfirewall/core/kmfnetzone.h4
-rw-r--r--kmyfirewall/core/kmfplugin.cpp2
-rw-r--r--kmyfirewall/core/kmfplugin.h2
-rw-r--r--kmyfirewall/core/kmfpluginfactory.cpp12
-rw-r--r--kmyfirewall/core/kmfpluginfactory.h6
-rw-r--r--kmyfirewall/core/kmfprotocol.cpp2
-rw-r--r--kmyfirewall/core/kmfprotocol.h2
-rw-r--r--kmyfirewall/core/kmfprotocolcategory.cpp2
-rw-r--r--kmyfirewall/core/kmfprotocolcategory.h2
-rw-r--r--kmyfirewall/core/kmfprotocollibrary.cpp2
-rw-r--r--kmyfirewall/core/kmfprotocollibrary.h2
-rw-r--r--kmyfirewall/core/kmfprotocolusage.cpp2
-rw-r--r--kmyfirewall/core/kmfprotocolusage.h2
-rw-r--r--kmyfirewall/core/kmfruleoptioneditinterface.cpp2
-rw-r--r--kmyfirewall/core/kmfruleoptioneditinterface.h2
-rw-r--r--kmyfirewall/core/kmfruletargetoptioneditinterface.cpp4
-rw-r--r--kmyfirewall/core/kmfruletargetoptioneditinterface.h2
-rw-r--r--kmyfirewall/core/kmftarget.cpp4
-rw-r--r--kmyfirewall/core/kmftarget.h2
-rw-r--r--kmyfirewall/core/kmfundoengine.cpp2
-rw-r--r--kmyfirewall/core/kprocesswrapper.cpp2
-rw-r--r--kmyfirewall/core/netfilterobject.cpp12
-rw-r--r--kmyfirewall/core/netfilterobject.h4
36 files changed, 98 insertions, 98 deletions
diff --git a/kmyfirewall/core/ipaddress.cpp b/kmyfirewall/core/ipaddress.cpp
index 8d74610..dc49fd6 100644
--- a/kmyfirewall/core/ipaddress.cpp
+++ b/kmyfirewall/core/ipaddress.cpp
@@ -203,14 +203,14 @@ int IPAddress::calcLenthToMask( IPAddress& addr) {
}
- int tqmask = 0;
+ int mask = 0;
for (int loop=0; loop<4; loop++) {
int div = 256;
while ( div > 1) {
div = div/2;
int test = m[loop] - div;
if ( test >-1) {
- tqmask=tqmask+1;
+ mask=mask+1;
m[loop]=test;
} else {
break;
@@ -218,8 +218,8 @@ int IPAddress::calcLenthToMask( IPAddress& addr) {
}
}
- // kdDebug() << "Returning: " << tqmask << endl;
- return tqmask;
+ // kdDebug() << "Returning: " << mask << endl;
+ return mask;
}
bool IPAddress::isValidAddress( IPAddress& addr) {
@@ -309,27 +309,27 @@ bool IPAddress::isValidMask( IPAddress& addr) {
bool IPAddress::hostsOnSameNetwork( IPAddress& host1, IPAddress& host2, int len ) {
// kdDebug() << "IPAddress::hostsOnSameNetwork( IPAddress&, IPAddress&, int )" << endl;
- IPAddress tqmask = IPAddress::calcNetworkMaskFromLength( len );
- return ( IPAddress::hostsOnSameNetwork( host1, host2, tqmask ) );
+ IPAddress mask = IPAddress::calcNetworkMaskFromLength( len );
+ return ( IPAddress::hostsOnSameNetwork( host1, host2, mask ) );
}
-bool IPAddress::hostsOnSameNetwork( IPAddress& host1, IPAddress& host2, IPAddress& tqmask ) {
+bool IPAddress::hostsOnSameNetwork( IPAddress& host1, IPAddress& host2, IPAddress& mask ) {
kdDebug() << "IPAddress::hostsOnSameNetwork( IPAddress&, IPAddress&, int )" << endl;
kdDebug() << "Host 1: " << host1.toString() << endl;
kdDebug() << "Host 2: " << host2.toString() << endl;
- kdDebug() << "Mask: " << tqmask.toString() << endl;
-// IPAddress tqmask = IPAddress::calcNetworkMaskFromLength( len );
+ kdDebug() << "Mask: " << mask.toString() << endl;
+// IPAddress mask = IPAddress::calcNetworkMaskFromLength( len );
- int nOctA1=host1.getDigit(0) & tqmask.getDigit(0);
- int nOctA2=host1.getDigit(1) & tqmask.getDigit(1);
- int nOctA3=host1.getDigit(2) & tqmask.getDigit(2);
- int nOctA4=host1.getDigit(3) & tqmask.getDigit(3);
+ int nOctA1=host1.getDigit(0) & mask.getDigit(0);
+ int nOctA2=host1.getDigit(1) & mask.getDigit(1);
+ int nOctA3=host1.getDigit(2) & mask.getDigit(2);
+ int nOctA4=host1.getDigit(3) & mask.getDigit(3);
- int nOctB1=host2.getDigit(0) & tqmask.getDigit(0);
- int nOctB2=host2.getDigit(1) & tqmask.getDigit(1);
- int nOctB3=host2.getDigit(2) & tqmask.getDigit(2);
- int nOctB4=host2.getDigit(3) & tqmask.getDigit(3);
+ int nOctB1=host2.getDigit(0) & mask.getDigit(0);
+ int nOctB2=host2.getDigit(1) & mask.getDigit(1);
+ int nOctB3=host2.getDigit(2) & mask.getDigit(2);
+ int nOctB4=host2.getDigit(3) & mask.getDigit(3);
if ((nOctA1==nOctB1) && (nOctA2==nOctB2) && (nOctA3==nOctB3) && (nOctA4==nOctB4)) {
kdDebug() << "Hosts on same net." << endl;
diff --git a/kmyfirewall/core/kmfcheckinput.cpp b/kmyfirewall/core/kmfcheckinput.cpp
index f1c3bc2..5a9d3c7 100644
--- a/kmyfirewall/core/kmfcheckinput.cpp
+++ b/kmyfirewall/core/kmfcheckinput.cpp
@@ -308,7 +308,7 @@ bool KMFCheckInput::checkPORTRANGE ( TQString inp ) {
bool KMFCheckInput::checkNetWork ( TQString inp ) {
bool valid_address = false;
- bool valid_tqmask = false;
+ bool valid_mask = false;
kdDebug() << "Checking for NETWORK: " << endl;
int delimiter = inp.find( "/" );
if ( delimiter == -1 ) {
@@ -316,21 +316,21 @@ bool KMFCheckInput::checkNetWork ( TQString inp ) {
return false;
} else {
TQString addr = inp.left( delimiter );
- TQString tqmask = inp.right( inp.length() - ( delimiter + 1 ) );
+ TQString mask = inp.right( inp.length() - ( delimiter + 1 ) );
kdDebug() << "Found address: " << addr << endl;
- kdDebug() << "Found tqmask: " << tqmask << endl;
- if ( tqmask.isEmpty() ) {
+ kdDebug() << "Found mask: " << mask << endl;
+ if ( mask.isEmpty() ) {
// kdDebug() << "Mask is Empty\n" << endl;
return false;
} else {
valid_address = checkIP( addr );
- valid_tqmask = checkIP( tqmask );
-// kdDebug() << "Mask address valid: " << valid_tqmask << endl;
- if ( !valid_tqmask ) {
- valid_tqmask = checkNetMask ( tqmask );
-// kdDebug() << "Mask number valid: " << valid_tqmask << endl;
+ valid_mask = checkIP( mask );
+// kdDebug() << "Mask address valid: " << valid_mask << endl;
+ if ( !valid_mask ) {
+ valid_mask = checkNetMask ( mask );
+// kdDebug() << "Mask number valid: " << valid_mask << endl;
}
- if ( !valid_address || !valid_tqmask ) {
+ if ( !valid_address || !valid_mask ) {
// kdDebug() << "This is no valid Network" << endl;
return false;
} else {
diff --git a/kmyfirewall/core/kmfcheckinput.h b/kmyfirewall/core/kmfcheckinput.h
index bc6ec1b..dede5b6 100644
--- a/kmyfirewall/core/kmfcheckinput.h
+++ b/kmyfirewall/core/kmfcheckinput.h
@@ -56,7 +56,7 @@ private: // functions
/** Check if inp is a MAC address */
bool checkMAC( TQString inp );
- /** Check if inp is a net tqmask */
+ /** Check if inp is a net mask */
bool checkNetMask ( TQString inp );
/** Check if inp is a network */
diff --git a/kmyfirewall/core/kmfcompilerinterface.h b/kmyfirewall/core/kmfcompilerinterface.h
index f9cb80a..88d2a0b 100644
--- a/kmyfirewall/core/kmfcompilerinterface.h
+++ b/kmyfirewall/core/kmfcompilerinterface.h
@@ -35,7 +35,7 @@ class KMFIPTDoc;
class KDE_EXPORT KMFCompilerInterface {
public:
-// KMFCompilerInterface( TQObject* tqparent , const char* name ) : KParts::Plugin( tqparent , name ) {};
+// KMFCompilerInterface( TQObject* parent , const char* name ) : KParts::Plugin( parent , name ) {};
KMFCompilerInterface();
virtual ~KMFCompilerInterface();
virtual void compile() = 0;
diff --git a/kmyfirewall/core/kmfdoc.cpp b/kmyfirewall/core/kmfdoc.cpp
index c119f34..15e08f5 100644
--- a/kmyfirewall/core/kmfdoc.cpp
+++ b/kmyfirewall/core/kmfdoc.cpp
@@ -62,8 +62,8 @@
namespace KMF {
-KMFDoc::KMFDoc( NetfilterObject *tqparent, const char *name ) : NetfilterObject( tqparent, name ) {
- kdDebug() << "KMFDoc::KMFDoc( TQObject *tqparent, const char *name ) : NetfilterObject( tqparent )" << endl;
+KMFDoc::KMFDoc( NetfilterObject *parent, const char *name ) : NetfilterObject( parent, name ) {
+ kdDebug() << "KMFDoc::KMFDoc( TQObject *parent, const char *name ) : NetfilterObject( parent )" << endl;
/* NetfilterObject::setName( i18n( "Unnamed Document" ) );
NetfilterObject::setDescription( i18n( "No Description Available" ) );*/
m_newSavePathNeeded = true;
diff --git a/kmyfirewall/core/kmfdoc.h b/kmyfirewall/core/kmfdoc.h
index f85c28c..ad60aa3 100644
--- a/kmyfirewall/core/kmfdoc.h
+++ b/kmyfirewall/core/kmfdoc.h
@@ -57,7 +57,7 @@ class KDE_EXPORT KMFDoc : public NetfilterObject {
Q_OBJECT
TQ_OBJECT
public:
- KMFDoc( NetfilterObject* tqparent, const char* name );
+ KMFDoc( NetfilterObject* parent, const char* name );
virtual ~KMFDoc();
diff --git a/kmyfirewall/core/kmfgenericdoc.cpp b/kmyfirewall/core/kmfgenericdoc.cpp
index 118eaf5..a97cf12 100644
--- a/kmyfirewall/core/kmfgenericdoc.cpp
+++ b/kmyfirewall/core/kmfgenericdoc.cpp
@@ -55,8 +55,8 @@
namespace KMF {
-KMFGenericDoc::KMFGenericDoc( NetfilterObject* tqparent, const char* name, KMFTarget* target ) : KMFDoc( tqparent, name ), KMFRulesetDoc( target ) {
- kdDebug() << "KMFGenericDoc::KMFGenericDoc( TQObject *tqparent, const char *name ) : KMFDoc( tqparent, name )" << endl;
+KMFGenericDoc::KMFGenericDoc( NetfilterObject* parent, const char* name, KMFTarget* target ) : KMFDoc( parent, name ), KMFRulesetDoc( target ) {
+ kdDebug() << "KMFGenericDoc::KMFGenericDoc( TQObject *parent, const char *name ) : KMFDoc( parent, name )" << endl;
m_zones.setAutoDelete( false );
m_zone_incoming = 0;
m_zone_outgoing = 0;
diff --git a/kmyfirewall/core/kmfiptdoc.cpp b/kmyfirewall/core/kmfiptdoc.cpp
index fc111cd..a566dd2 100644
--- a/kmyfirewall/core/kmfiptdoc.cpp
+++ b/kmyfirewall/core/kmfiptdoc.cpp
@@ -79,7 +79,7 @@
namespace KMF {
-KMFIPTDoc::KMFIPTDoc( NetfilterObject *tqparent, const char *name, KMFTarget* target ) : KMFDoc( tqparent, name ), KMFRulesetDoc( target ) {
+KMFIPTDoc::KMFIPTDoc( NetfilterObject *parent, const char *name, KMFTarget* target ) : KMFDoc( parent, name ), KMFRulesetDoc( target ) {
initDoc();
}
diff --git a/kmyfirewall/core/kmfnethost.cpp b/kmyfirewall/core/kmfnethost.cpp
index 20bdefa..1b5cac3 100644
--- a/kmyfirewall/core/kmfnethost.cpp
+++ b/kmyfirewall/core/kmfnethost.cpp
@@ -46,7 +46,7 @@
namespace KMF {
-KMFNetHost::KMFNetHost( NetfilterObject *tqparent, const char* name, const TQString& hostName, KMFNetwork* net ) : KMFTarget( tqparent, name, hostName, net ) {
+KMFNetHost::KMFNetHost( NetfilterObject *parent, const char* name, const TQString& hostName, KMFNetwork* net ) : KMFTarget( parent, name, hostName, net ) {
m_logIncoming = false;
m_logOutgoing = false;
m_guiName = i18n("New Host");
@@ -56,7 +56,7 @@ KMFNetHost::KMFNetHost( NetfilterObject *tqparent, const char* name, const TQStr
m_protocols.setAutoDelete( false );
setName( hostName );
// m_object_type = NETHOST;
- if ( KMFNetZone* zone = dynamic_cast<KMFNetZone*> ( tqparent ) ) {
+ if ( KMFNetZone* zone = dynamic_cast<KMFNetZone*> ( parent ) ) {
m_zone = zone;
m_address->setAddress( m_zone->address()->toString() );
} else {
diff --git a/kmyfirewall/core/kmfnethost.h b/kmyfirewall/core/kmfnethost.h
index dd30f4a..8181f23 100644
--- a/kmyfirewall/core/kmfnethost.h
+++ b/kmyfirewall/core/kmfnethost.h
@@ -57,7 +57,7 @@ class KDE_EXPORT KMFNetHost : public KMFTarget {
Q_OBJECT
TQ_OBJECT
public:
- KMFNetHost( NetfilterObject *tqparent, const char* name, const TQString& Hostname, KMFNetwork* net );
+ KMFNetHost( NetfilterObject *parent, const char* name, const TQString& Hostname, KMFNetwork* net );
virtual ~KMFNetHost();
virtual int type();
diff --git a/kmyfirewall/core/kmfnetwork.cpp b/kmyfirewall/core/kmfnetwork.cpp
index 0b269e5..3a15ab6 100644
--- a/kmyfirewall/core/kmfnetwork.cpp
+++ b/kmyfirewall/core/kmfnetwork.cpp
@@ -56,8 +56,8 @@
namespace KMF {
-KMFNetwork::KMFNetwork( NetfilterObject* tqparent, const char* name, KMyFirewallInterface* ) : KMFDoc( tqparent, name ) {
- kdDebug() << "KMFNetwork::KMFNetwork( TQObject *tqparent, const char *name ) : KMFDoc( tqparent, name )" << endl;
+KMFNetwork::KMFNetwork( NetfilterObject* parent, const char* name, KMyFirewallInterface* ) : KMFDoc( parent, name ) {
+ kdDebug() << "KMFNetwork::KMFNetwork( TQObject *parent, const char *name ) : KMFDoc( parent, name )" << endl;
m_target = 0;
m_myNetwork = 0;
diff --git a/kmyfirewall/core/kmfnetzone.cpp b/kmyfirewall/core/kmfnetzone.cpp
index 042d562..9b4a974 100644
--- a/kmyfirewall/core/kmfnetzone.cpp
+++ b/kmyfirewall/core/kmfnetzone.cpp
@@ -50,8 +50,8 @@
namespace KMF {
-KMFNetZone::KMFNetZone( NetfilterObject *tqparent, const char* name, const TQString& zoneName ) : NetfilterObject( tqparent, name ) {
- kdDebug() << "KMFNetZone::KMFNetZone( NetfilterObject *tqparent, const char* name, const TQString& zoneName )" << endl;
+KMFNetZone::KMFNetZone( NetfilterObject *parent, const char* name, const TQString& zoneName ) : NetfilterObject( parent, name ) {
+ kdDebug() << "KMFNetZone::KMFNetZone( NetfilterObject *parent, const char* name, const TQString& zoneName )" << endl;
m_doc = 0;
m_network = 0;
m_zone = 0;
@@ -67,14 +67,14 @@ KMFNetZone::KMFNetZone( NetfilterObject *tqparent, const char* name, const TQStr
} else {
setName( zoneName );
}
- if ( KMFNetZone * zone = dynamic_cast<KMFNetZone*> ( tqparent ) ) {
+ if ( KMFNetZone * zone = dynamic_cast<KMFNetZone*> ( parent ) ) {
m_zoneType = NODE;
m_zone = zone;
- setZone( *m_zone->address(), m_zone->maskLength() /* , *m_zone->tqmask() */ );
- } else if ( KMFGenericDoc * doc = dynamic_cast<KMFGenericDoc*> ( tqparent ) ) {
+ setZone( *m_zone->address(), m_zone->maskLength() /* , *m_zone->mask() */ );
+ } else if ( KMFGenericDoc * doc = dynamic_cast<KMFGenericDoc*> ( parent ) ) {
m_zoneType = ROOT;
m_doc = doc;
- } else if ( KMFNetwork * doc = dynamic_cast<KMFNetwork*> ( tqparent ) ) {
+ } else if ( KMFNetwork * doc = dynamic_cast<KMFNetwork*> ( parent ) ) {
m_zoneType = ROOT;
m_network = doc;
}
@@ -93,9 +93,9 @@ KMFNetZone::~KMFNetZone() {
}
int KMFNetZone::operator==( const KMFNetZone& zone ) {
- if ( IPAddress::calcLenthToMask( *tqmask() ) > IPAddress::calcLenthToMask( *zone.tqmask() ) ) {
+ if ( IPAddress::calcLenthToMask( *mask() ) > IPAddress::calcLenthToMask( *zone.mask() ) ) {
return 1;
- } else if ( IPAddress::calcLenthToMask( *tqmask() ) == IPAddress::calcLenthToMask( *zone.tqmask() ) ){
+ } else if ( IPAddress::calcLenthToMask( *mask() ) == IPAddress::calcLenthToMask( *zone.mask() ) ){
return 0;
} else {
return -1;
@@ -103,9 +103,9 @@ int KMFNetZone::operator==( const KMFNetZone& zone ) {
}
bool KMFNetZone::isSameZone( KMFNetZone* zone ) {
- if ( IPAddress::calcLenthToMask( *tqmask() ) > IPAddress::calcLenthToMask( *zone->tqmask() ) ) {
+ if ( IPAddress::calcLenthToMask( *mask() ) > IPAddress::calcLenthToMask( *zone->mask() ) ) {
return false;
- } else if ( IPAddress::calcLenthToMask( *tqmask() ) == IPAddress::calcLenthToMask( *zone->tqmask() ) ){
+ } else if ( IPAddress::calcLenthToMask( *mask() ) == IPAddress::calcLenthToMask( *zone->mask() ) ){
return true;
} else {
return false;
@@ -797,9 +797,9 @@ const TQDomDocument& KMFNetZone::getDOMTree() {
TQString num;
from.setAttribute( XML::Address_Attribute, address()->toString() );
- TQDomElement tqmask = doc.createElement( XML::NetMask_Element );
- root.appendChild( tqmask );
- tqmask.setAttribute( XML::Address_Attribute, maskLength() );
+ TQDomElement mask = doc.createElement( XML::NetMask_Element );
+ root.appendChild( mask );
+ mask.setAttribute( XML::Address_Attribute, maskLength() );
TQPtrListIterator<KMFNetZone> it ( m_zones );
while ( it.current() ) {
@@ -867,7 +867,7 @@ void KMFNetZone::loadXML( TQDomNode root, TQStringList& errors ) {
if ( ok ) {
setMaskLength( len );
} else {
- kdDebug() << "Parsing tqmask failed" << endl;
+ kdDebug() << "Parsing mask failed" << endl;
}
}
}
diff --git a/kmyfirewall/core/kmfnetzone.h b/kmyfirewall/core/kmfnetzone.h
index 919fcf4..8b3fed9 100644
--- a/kmyfirewall/core/kmfnetzone.h
+++ b/kmyfirewall/core/kmfnetzone.h
@@ -53,7 +53,7 @@ class KDE_EXPORT KMFNetZone : public NetfilterObject {
Q_OBJECT
TQ_OBJECT
public:
- KMFNetZone( NetfilterObject *tqparent, const char* objectname, const TQString& name );
+ KMFNetZone( NetfilterObject *parent, const char* objectname, const TQString& name );
virtual ~KMFNetZone();
@@ -68,7 +68,7 @@ public:
bool isSameZone( KMFNetZone* );
- IPAddress* tqmask() const {
+ IPAddress* mask() const {
IPAddress *addr = new IPAddress();
addr->setAddress( IPAddress::calcNetworkMaskFromLength( m_maskLen ).toString() );
return addr;
diff --git a/kmyfirewall/core/kmfplugin.cpp b/kmyfirewall/core/kmfplugin.cpp
index 26b4687..1780bf4 100644
--- a/kmyfirewall/core/kmfplugin.cpp
+++ b/kmyfirewall/core/kmfplugin.cpp
@@ -29,7 +29,7 @@
namespace KMF {
-KMFPlugin::KMFPlugin( TQObject* tqparent , const char* name ) : KParts::Plugin( tqparent , name ) {
+KMFPlugin::KMFPlugin( TQObject* parent , const char* name ) : KParts::Plugin( parent , name ) {
m_err = new KMFError();
}
diff --git a/kmyfirewall/core/kmfplugin.h b/kmyfirewall/core/kmfplugin.h
index d15c396..ac2e74a 100644
--- a/kmyfirewall/core/kmfplugin.h
+++ b/kmyfirewall/core/kmfplugin.h
@@ -37,7 +37,7 @@ class KMFError;
class KDE_EXPORT KMFPlugin : public KParts::Plugin {
public:
- KMFPlugin( TQObject* tqparent , const char* name );
+ KMFPlugin( TQObject* parent , const char* name );
virtual ~KMFPlugin();
void setOutputWidget( TQWidget* wid );
void showEditor();
diff --git a/kmyfirewall/core/kmfpluginfactory.cpp b/kmyfirewall/core/kmfpluginfactory.cpp
index 68d1533..8d12e05 100644
--- a/kmyfirewall/core/kmfpluginfactory.cpp
+++ b/kmyfirewall/core/kmfpluginfactory.cpp
@@ -42,7 +42,7 @@ KMFPluginFactory::KMFPluginFactory() {}
KMFPluginFactory::~KMFPluginFactory() {}
-KParts::ReadWritePart* KMFPluginFactory::KMFMainView( KParts::MainWindow* tqparent, KMFError* err ) {
+KParts::ReadWritePart* KMFPluginFactory::KMFMainView( KParts::MainWindow* parent, KMFError* err ) {
err->setErrType( KMFError::OK );
TQString libName;
if ( KMFConfig::useGenericInterface() ) {
@@ -55,7 +55,7 @@ KParts::ReadWritePart* KMFPluginFactory::KMFMainView( KParts::MainWindow* tqpare
KLibFactory * factory = KLibLoader::self() ->factory( libName.latin1() );
if ( factory ) {
- KParts::ReadWritePart * m_ruleeditpart = static_cast<KParts::ReadWritePart *>( factory->create( TQT_TQOBJECT(tqparent),
+ KParts::ReadWritePart * m_ruleeditpart = static_cast<KParts::ReadWritePart *>( factory->create( TQT_TQOBJECT(parent),
libName.latin1() , "KParts::ReadWritePart" ) );
if ( m_ruleeditpart ) {
@@ -105,7 +105,7 @@ TQValueList<KMFCompilerInterface*>* KMFPluginFactory::CompilersForInstaller( con
return list;
}
-TQPtrList<KMFRuleOptionEditInterface>* KMFPluginFactory::KMFRuleOptionEditors( TQObject *tqparent ){
+TQPtrList<KMFRuleOptionEditInterface>* KMFPluginFactory::KMFRuleOptionEditors( TQObject *parent ){
TQPtrList<KMFRuleOptionEditInterface> *list = new TQPtrList<KMFRuleOptionEditInterface>;
KTrader::OfferList offers = KTrader::self()->query( "KMyFirewall/RuleOptionEdit");
kdDebug() << "Query performed" << endl;
@@ -119,7 +119,7 @@ TQPtrList<KMFRuleOptionEditInterface>* KMFPluginFactory::KMFRuleOptionEditors( T
if ( !factory ) {
kdDebug() << "Couldn't load plugin: " << ptr->name() << endl;
}
- if ( KMFRuleOptionEditInterface *part = dynamic_cast<KMFRuleOptionEditInterface*> ( factory->create( tqparent , "KMFRuleOptionEditInterface") ) ) {
+ if ( KMFRuleOptionEditInterface *part = dynamic_cast<KMFRuleOptionEditInterface*> ( factory->create( parent , "KMFRuleOptionEditInterface") ) ) {
if ( ! part ) {
KMessageBox::error(0, "Couldn't load plugin");
}
@@ -130,7 +130,7 @@ TQPtrList<KMFRuleOptionEditInterface>* KMFPluginFactory::KMFRuleOptionEditors( T
return list;
}
-TQPtrList<KMFRuleTargetOptionEditInterface>* KMFPluginFactory::KMFRuleTargetOptionEditors( TQObject *tqparent ) {
+TQPtrList<KMFRuleTargetOptionEditInterface>* KMFPluginFactory::KMFRuleTargetOptionEditors( TQObject *parent ) {
TQPtrList<KMFRuleTargetOptionEditInterface> *list = new TQPtrList<KMFRuleTargetOptionEditInterface>;
KTrader::OfferList offers = KTrader::self()->query( "KMyFirewall/RuleTargetOptionEdit");
kdDebug() << "Query performed" << endl;
@@ -144,7 +144,7 @@ TQPtrList<KMFRuleTargetOptionEditInterface>* KMFPluginFactory::KMFRuleTargetOpti
if ( !factory ) {
kdDebug() << "Couldn't load plugin: " << ptr->name() << endl;
}
- if ( KMFRuleTargetOptionEditInterface *part = dynamic_cast<KMFRuleTargetOptionEditInterface*> ( factory->create( tqparent , "KMFRuleTargetOptionEditInterface") ) ) {
+ if ( KMFRuleTargetOptionEditInterface *part = dynamic_cast<KMFRuleTargetOptionEditInterface*> ( factory->create( parent , "KMFRuleTargetOptionEditInterface") ) ) {
if ( ! part ) {
KMessageBox::error(0, "Couldn't load plugin");
}
diff --git a/kmyfirewall/core/kmfpluginfactory.h b/kmyfirewall/core/kmfpluginfactory.h
index 46bfc85..5ae7288 100644
--- a/kmyfirewall/core/kmfpluginfactory.h
+++ b/kmyfirewall/core/kmfpluginfactory.h
@@ -40,12 +40,12 @@ private:
KMFPluginFactory();
~KMFPluginFactory();
public:
-static TQPtrList<KMFRuleOptionEditInterface>* KMFRuleOptionEditors( TQObject *tqparent );
+static TQPtrList<KMFRuleOptionEditInterface>* KMFRuleOptionEditors( TQObject *parent );
-static TQPtrList<KMFRuleTargetOptionEditInterface>* KMFRuleTargetOptionEditors( TQObject *tqparent );
+static TQPtrList<KMFRuleTargetOptionEditInterface>* KMFRuleTargetOptionEditors( TQObject *parent );
static TQValueList<KMFCompilerInterface*>* CompilersForInstaller( const TQString& osName );
-static KParts::ReadWritePart* KMFMainView( KParts::MainWindow* tqparent, KMFError* err );
+static KParts::ReadWritePart* KMFMainView( KParts::MainWindow* parent, KMFError* err );
private:
static KMFCompilerInterface* KMFCompiler( KMFTarget* );
diff --git a/kmyfirewall/core/kmfprotocol.cpp b/kmyfirewall/core/kmfprotocol.cpp
index 6e86280..daec2e7 100644
--- a/kmyfirewall/core/kmfprotocol.cpp
+++ b/kmyfirewall/core/kmfprotocol.cpp
@@ -55,7 +55,7 @@
namespace KMF {
KMFProtocol::KMFProtocol( KMFProtocolCategory* protCat, const char* name ) : NetfilterObject( protCat, name ) {
- // kdDebug() << "KMFProtocol::KMFProtocol( NetfilterObject* tqparent, const char* name )" << endl;
+ // kdDebug() << "KMFProtocol::KMFProtocol( NetfilterObject* parent, const char* name )" << endl;
m_category = protCat;
m_customProtocol = true;
m_tcpPorts.clear();
diff --git a/kmyfirewall/core/kmfprotocol.h b/kmyfirewall/core/kmfprotocol.h
index d742fbb..092a204 100644
--- a/kmyfirewall/core/kmfprotocol.h
+++ b/kmyfirewall/core/kmfprotocol.h
@@ -98,7 +98,7 @@ public:
KMFProtocolUsage *createUsage();
private:
- KMFProtocol( KMFProtocolCategory* tqparent, const char* name );
+ KMFProtocol( KMFProtocolCategory* parent, const char* name );
private:
TQValueList<KMFProtocolUsage*> m_usages;
diff --git a/kmyfirewall/core/kmfprotocolcategory.cpp b/kmyfirewall/core/kmfprotocolcategory.cpp
index 659db47..d5d7562 100644
--- a/kmyfirewall/core/kmfprotocolcategory.cpp
+++ b/kmyfirewall/core/kmfprotocolcategory.cpp
@@ -58,7 +58,7 @@ KMFProtocolCategory* KMFProtocolCategory::getCustomCategory() {
-KMFProtocolCategory::KMFProtocolCategory ( NetfilterObject* tqparent, const char* name ) : NetfilterObject ( tqparent, name ) {
+KMFProtocolCategory::KMFProtocolCategory ( NetfilterObject* parent, const char* name ) : NetfilterObject ( parent, name ) {
// m_protocols;
}
diff --git a/kmyfirewall/core/kmfprotocolcategory.h b/kmyfirewall/core/kmfprotocolcategory.h
index 1a650a6..7f23c42 100644
--- a/kmyfirewall/core/kmfprotocolcategory.h
+++ b/kmyfirewall/core/kmfprotocolcategory.h
@@ -77,7 +77,7 @@ private:
private: // DATA
- KMFProtocolCategory( NetfilterObject* tqparent, const char* name );
+ KMFProtocolCategory( NetfilterObject* parent, const char* name );
TQString m_icon;
TQValueList< KMFProtocol* > m_protocols;
diff --git a/kmyfirewall/core/kmfprotocollibrary.cpp b/kmyfirewall/core/kmfprotocollibrary.cpp
index 8d589f9..2b4e5c8 100644
--- a/kmyfirewall/core/kmfprotocollibrary.cpp
+++ b/kmyfirewall/core/kmfprotocollibrary.cpp
@@ -57,7 +57,7 @@ KMFProtocolLibrary* KMFProtocolLibrary::instance() {
}
/** End Static Stuff **/
-KMFProtocolLibrary::KMFProtocolLibrary( TQObject* tqparent, const char* name ) : TQObject( tqparent, name ) {
+KMFProtocolLibrary::KMFProtocolLibrary( TQObject* parent, const char* name ) : TQObject( parent, name ) {
m_libraryLoaded = false;
forceProtocolLibraryReload();
}
diff --git a/kmyfirewall/core/kmfprotocollibrary.h b/kmyfirewall/core/kmfprotocollibrary.h
index 669102a..ccbd9ce 100644
--- a/kmyfirewall/core/kmfprotocollibrary.h
+++ b/kmyfirewall/core/kmfprotocollibrary.h
@@ -60,7 +60,7 @@ private:
private:
- KMFProtocolLibrary( TQObject* tqparent, const char* name );
+ KMFProtocolLibrary( TQObject* parent, const char* name );
KMFProtocolLibrary();
bool m_libraryLoaded;
diff --git a/kmyfirewall/core/kmfprotocolusage.cpp b/kmyfirewall/core/kmfprotocolusage.cpp
index 2dd65fa..90e68a1 100644
--- a/kmyfirewall/core/kmfprotocolusage.cpp
+++ b/kmyfirewall/core/kmfprotocolusage.cpp
@@ -43,7 +43,7 @@
namespace KMF {
-KMFProtocolUsage::KMFProtocolUsage( NetfilterObject* tqparent, const char* name ) : NetfilterObject( tqparent, name ) {
+KMFProtocolUsage::KMFProtocolUsage( NetfilterObject* parent, const char* name ) : NetfilterObject( parent, name ) {
m_protocol = 0;
m_limit_interval = "minute";
m_limit = -1;
diff --git a/kmyfirewall/core/kmfprotocolusage.h b/kmyfirewall/core/kmfprotocolusage.h
index c85241d..324c222 100644
--- a/kmyfirewall/core/kmfprotocolusage.h
+++ b/kmyfirewall/core/kmfprotocolusage.h
@@ -84,7 +84,7 @@ public slots:
void slotOnProtocolDeleted( TQObject* protocol );
private:
- KMFProtocolUsage( NetfilterObject* tqparent, const char* name );
+ KMFProtocolUsage( NetfilterObject* parent, const char* name );
TQGuardedPtr<KMFProtocol> m_protocol;
TQString m_limit_interval;
int m_limit;
diff --git a/kmyfirewall/core/kmfruleoptioneditinterface.cpp b/kmyfirewall/core/kmfruleoptioneditinterface.cpp
index e07262d..02390c5 100644
--- a/kmyfirewall/core/kmfruleoptioneditinterface.cpp
+++ b/kmyfirewall/core/kmfruleoptioneditinterface.cpp
@@ -18,7 +18,7 @@
namespace KMF {
-KMFRuleOptionEditInterface::KMFRuleOptionEditInterface(TQObject *tqparent, const char* name ) : KMFPlugin( tqparent, name ) {
+KMFRuleOptionEditInterface::KMFRuleOptionEditInterface(TQObject *parent, const char* name ) : KMFPlugin( parent, name ) {
kdDebug() << "KMFRuleOptionEditInterface::KMFRuleOptionEditInterface()" << endl;
}
diff --git a/kmyfirewall/core/kmfruleoptioneditinterface.h b/kmyfirewall/core/kmfruleoptioneditinterface.h
index 08ba33c..e8821c2 100644
--- a/kmyfirewall/core/kmfruleoptioneditinterface.h
+++ b/kmyfirewall/core/kmfruleoptioneditinterface.h
@@ -13,7 +13,7 @@ class IPTRule;
class KDE_EXPORT KMFRuleOptionEditInterface : public KMFPlugin {
public:
- KMFRuleOptionEditInterface(TQObject *tqparent = 0, const char* name = 0);
+ KMFRuleOptionEditInterface(TQObject *parent = 0, const char* name = 0);
virtual ~KMFRuleOptionEditInterface();
virtual void loadRule( IPTRule* ) = 0;
virtual TQWidget* editWidget() = 0;
diff --git a/kmyfirewall/core/kmfruletargetoptioneditinterface.cpp b/kmyfirewall/core/kmfruletargetoptioneditinterface.cpp
index 667a8f2..845c36c 100644
--- a/kmyfirewall/core/kmfruletargetoptioneditinterface.cpp
+++ b/kmyfirewall/core/kmfruletargetoptioneditinterface.cpp
@@ -13,8 +13,8 @@
namespace KMF {
-KMFRuleTargetOptionEditInterface::KMFRuleTargetOptionEditInterface(TQObject *tqparent, const char *name)
- : KMFRuleOptionEditInterface(tqparent, name) {
+KMFRuleTargetOptionEditInterface::KMFRuleTargetOptionEditInterface(TQObject *parent, const char *name)
+ : KMFRuleOptionEditInterface(parent, name) {
// m_managedTargets << "DNAT" << "SNAT";
}
diff --git a/kmyfirewall/core/kmfruletargetoptioneditinterface.h b/kmyfirewall/core/kmfruletargetoptioneditinterface.h
index d05cfc4..c2c2c43 100644
--- a/kmyfirewall/core/kmfruletargetoptioneditinterface.h
+++ b/kmyfirewall/core/kmfruletargetoptioneditinterface.h
@@ -25,7 +25,7 @@
namespace KMF {
class KDE_EXPORT KMFRuleTargetOptionEditInterface : public KMFRuleOptionEditInterface {
public:
- KMFRuleTargetOptionEditInterface(TQObject *tqparent = 0, const char *name = 0);
+ KMFRuleTargetOptionEditInterface(TQObject *parent = 0, const char *name = 0);
virtual ~KMFRuleTargetOptionEditInterface();
diff --git a/kmyfirewall/core/kmftarget.cpp b/kmyfirewall/core/kmftarget.cpp
index 4e363f6..7ea64d1 100644
--- a/kmyfirewall/core/kmftarget.cpp
+++ b/kmyfirewall/core/kmftarget.cpp
@@ -44,8 +44,8 @@ Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2001-2008
namespace KMF {
-KMFTarget::KMFTarget( NetfilterObject *tqparent, const char* name, const TQString&, KMFNetwork* net ) : NetfilterObject( tqparent, name ) {
- kdDebug() << "KMFTarget::KMFTarget( NetfilterObject *tqparent, const TQString& name )" << endl;
+KMFTarget::KMFTarget( NetfilterObject *parent, const char* name, const TQString&, KMFNetwork* net ) : NetfilterObject( parent, name ) {
+ kdDebug() << "KMFTarget::KMFTarget( NetfilterObject *parent, const TQString& name )" << endl;
m_network = net;
m_address = new IPAddress( 0,0,0,0 );
m_ssh_port = 22;
diff --git a/kmyfirewall/core/kmftarget.h b/kmyfirewall/core/kmftarget.h
index 35e9ae2..e0fe3fd 100644
--- a/kmyfirewall/core/kmftarget.h
+++ b/kmyfirewall/core/kmftarget.h
@@ -48,7 +48,7 @@ class KDE_EXPORT KMFTarget : public NetfilterObject {
Q_OBJECT
TQ_OBJECT
public:
- KMFTarget( NetfilterObject *tqparent, const char* name, const TQString& targetName, KMFNetwork* net );
+ KMFTarget( NetfilterObject *parent, const char* name, const TQString& targetName, KMFNetwork* net );
~KMFTarget();
diff --git a/kmyfirewall/core/kmfundoengine.cpp b/kmyfirewall/core/kmfundoengine.cpp
index bf7511f..972eced 100644
--- a/kmyfirewall/core/kmfundoengine.cpp
+++ b/kmyfirewall/core/kmfundoengine.cpp
@@ -37,7 +37,7 @@ KMFUndoEngine* KMFUndoEngine::instance() {
}
//##### end static stuff
-KMFUndoEngine::KMFUndoEngine( TQObject* tqparent, const char* name ) : TQObject( tqparent, name ) {
+KMFUndoEngine::KMFUndoEngine( TQObject* parent, const char* name ) : TQObject( parent, name ) {
MAX_UNDO = 10;
m_in_transaction = false;
is_saved = true;
diff --git a/kmyfirewall/core/kprocesswrapper.cpp b/kmyfirewall/core/kprocesswrapper.cpp
index 63efff3..26412f1 100644
--- a/kmyfirewall/core/kprocesswrapper.cpp
+++ b/kmyfirewall/core/kprocesswrapper.cpp
@@ -44,7 +44,7 @@ KProcessWrapper* KProcessWrapper::instance() {
-KProcessWrapper::KProcessWrapper( TQObject* tqparent, const char* name ) : TQObject( tqparent, name ) {
+KProcessWrapper::KProcessWrapper( TQObject* parent, const char* name ) : TQObject( parent, name ) {
m_stderrbuf = new TQString( "" );
m_stdoutbuf = new TQString( "" );
m_childproc = new KProcess();
diff --git a/kmyfirewall/core/netfilterobject.cpp b/kmyfirewall/core/netfilterobject.cpp
index 691aaf1..b975ee0 100644
--- a/kmyfirewall/core/netfilterobject.cpp
+++ b/kmyfirewall/core/netfilterobject.cpp
@@ -63,10 +63,10 @@ int NetfilterObject::objectCount( int type ) {
//########### end static stuff
-NetfilterObject::NetfilterObject( NetfilterObject *tqparent, const char* name ) : TQObject( tqparent, name ) {
- // kdDebug() << "NetfilterObject::( NetfilterObject *tqparent " << name << " )" << endl;
+NetfilterObject::NetfilterObject( NetfilterObject *parent, const char* name ) : TQObject( parent, name ) {
+ // kdDebug() << "NetfilterObject::( NetfilterObject *parent " << name << " )" << endl;
m_uuid = TQUuid::createUuid();
- m_parent = tqparent;
+ m_parent = parent;
m_name = i18n( "Untitled" );
m_desc = i18n( "No Description Available" );
m_uuid_dict->insert( uuid(), this, true );
@@ -104,11 +104,11 @@ void NetfilterObject::setUuid( const TQUuid& newUuid ) {
m_uuid_dict->insert( m_uuid, this, true );
}
-void NetfilterObject::setParent( NetfilterObject *tqparent ) {
- if ( ! tqparent || tqparent == m_parent ) {
+void NetfilterObject::setParent( NetfilterObject *parent ) {
+ if ( ! parent || parent == m_parent ) {
return;
}
- m_parent = tqparent;
+ m_parent = parent;
changed();
}
diff --git a/kmyfirewall/core/netfilterobject.h b/kmyfirewall/core/netfilterobject.h
index 39e6057..5b316a8 100644
--- a/kmyfirewall/core/netfilterobject.h
+++ b/kmyfirewall/core/netfilterobject.h
@@ -133,14 +133,14 @@ public:
/** Load configuration from the given TQDdomDocument */
virtual void loadXML( TQDomNode, TQStringList& errors ) = 0;
- /** Set the tqparent object */
+ /** Set the parent object */
void setParent( NetfilterObject* );
/** check if the object is a (indirect) child of the object
with the given id */
bool isChildOf( const TQUuid& uuid );
- /** set the changed flag, and calling changed( int id ) in the tqparent
+ /** set the changed flag, and calling changed( int id ) in the parent
object with it's own id */
void changed();
diff --git a/kmyfirewall/core/ipaddress.h b/kmyfirewall/core/ipaddress.h
index d80cd44..4252c7c 100644
--- a/kmyfirewall/core/ipaddress.h
+++ b/kmyfirewall/core/ipaddress.h
@@ -79,25 +79,25 @@ private:
// static stuff
public:
/** Calculates the nettqmask from the tqmask length
e.g. 255.255.255.0 -> 24 */
static IPAddress& calcNetworkMaskFromLength( int maskLen );
/** Calculates the given nettqmask length to the net tqmask.
e.g. 24 -> 255.255.255.0 */
static int calcLenthToMask( IPAddress& );
/** Returns true it the given adddress is a valid net tqmask */
static bool isValidMask( IPAddress& );
/** Returns true it the given adddress is a valid net tqmask */
static bool isValidAddress( IPAddress& );
/** Checks if the the addresses are on the same network. */
static bool hostsOnSameNetwork( IPAddress&, IPAddress&, int maskLen );
/** Checks if the the addresses are on the same network. */
- static bool hostsOnSameNetwork( IPAddress&, IPAddress&, IPAddress& tqmask );
+ static bool hostsOnSameNetwork( IPAddress&, IPAddress&, IPAddress& mask );
private:
private: static int calcLenthToMaskDigit( int nMask, int *nextOne );
@@ -79,25 +79,25 @@ private:
// static stuff
public:
- /** Calculates the nettqmask from the tqmask length
+ /** Calculates the netmask from the mask length
e.g. 255.255.255.0 -> 24 */
static IPAddress& calcNetworkMaskFromLength( int maskLen );
@@ -79,25 +79,25 @@ private:
e.g. 255.255.255.0 -> 24 */
static IPAddress& calcNetworkMaskFromLength( int maskLen );
- /** Calculates the given nettqmask length to the net tqmask.
+ /** Calculates the given netmask length to the net mask.
e.g. 24 -> 255.255.255.0 */
static int calcLenthToMask( IPAddress& );
@@ -79,25 +79,25 @@ private:
e.g. 24 -> 255.255.255.0 */
static int calcLenthToMask( IPAddress& );
- /** Returns true it the given adddress is a valid net tqmask */
+ /** Returns true it the given adddress is a valid net mask */
static bool isValidMask( IPAddress& );
@@ -79,25 +79,25 @@ private:
static bool isValidMask( IPAddress& );
- /** Returns true it the given adddress is a valid net tqmask */
+ /** Returns true it the given adddress is a valid net mask */
static bool isValidAddress( IPAddress& );
/** Checks if the the addresses are on the same network. */